<!--
 *  Copyright 2013-2014  Andreas Cord-Landwehr <cordlandwehr@kde.org>
 *
 *  Licensed under the Creative Commons Attribution-Share Alike 3.0 Unported licence
 *  available at http://creativecommons.org/licenses/by-sa/3.0/
-->
<!DOCTYPE html>
<html>
<head>
<title>Script API Documentation Plugin: Object</title>
<link rel="stylesheet" href="bootstrap.css" />
<link rel="stylesheet" href="bootstrap-apiview.css" />
</head>
<body>

<div style="margin: 10pt" id="rocs-content-text">
<h1>{{ object.title }}</h1>

{% for para in object.description %}
<p>{{ para }}</p>
{% endfor %}

{% if object.syntaxExample %}
<h2>{{ i18nSyntax }}</h2>
<pre>{{ object.syntaxExample }}</pre>

{% endif %}

{% if properties %}
<h2 id="properties" style="line-height: 1em;">{{ i18nProperties }}</h2>
<ul>
{% for property in properties %}
    <li id="{{ property.documentAnchor }}">
        <strong>{{ property.name }}</strong> :
        {% if property.typeLink %}
        <a href="http://virtual/{{ property.typeLink }}">{{ property.type }}</a>
        {% else %}
        {{ property.type }}
        {% endif %}
        {% for paragraph in property.description %}
        <p style="font-style: italic">{{ paragraph }}</p>
        {% endfor %}
    </li>
{% endfor %}
</ul>
{% endif %}

{% if methods %}
<h2 id="methods">{{ i18nMethods }}</h2>
<ul>
{% for method in methods %}
<li><a href="#{{ method.documentAnchor }}">{{ method.name }}</a></li>
{% endfor %}
</ul>

<h3>{{ i18nDetailedDescription }}</h3>
{% for method in methods %}
    <h4 id="{{ method.documentAnchor }}">{{ method.name }}</h4>
    {% for paragraph in method.description %}
        <p>{{ paragraph }}</p>
    {% endfor %}
    {% if method.parameters.count %}
    <table class="table-striped" style="width: 100%">
    <thead class="rocs-parameter-thead">
    <tr><th style="width: 30%">{{ i18nParameter }}</th><th>{{ i18nDescription }}</th></tr>
    </thead>
    <tbody>
    {% for parameter in method.parameters %}
        <tr>
            <td><strong>{{ parameter.name }}</strong> :
            {% if parameter.typeLink %}
            <a href="http://virtual/{{ parameter.typeLink }}">{{ parameter.type }}</a>
            {% else %}
            {{ parameter.type }}
            {% endif %}
            </td>
            <td>{{ parameter.info }}</td>
        </tr>
    {% endfor %}
    </tbody>
    </table>
    {% endif %}
    <p><b>{{ i18nReturnType }}</b> :
        {% if method.returnTypeLink %}
        <a href="http://virtual/{{ method.returnTypeLink }}">{{ method.returnType }}</a>
        {% else %}
        {{ method.returnType }}
        {% endif %}
    </p>
{% endfor %}
{% endif %}
</div>
</body>
</html>
