/*!
 *  Copyright 2013  Andreas Cord-Landwehr <cola@uni-paderborn.de>
 *
 *  Licensed under the Creative Commons Attribution-Share Alike 3.0 Unported licence
 *  available at http://creativecommons.org/licenses/by-sa/3.0/
 */

#rocs-content-text h1, #rocs-content-text h2
{
  margin-bottom: 10px;
  padding-bottom: 5px;
  border-bottom-width: 1px;
  border-bottom-style: solid;
  border-bottom-color: #dadada;
}

.rocs-parameter-thead
{
    background-color:#dddddd
}
