/*!
 * Bootstrap v3.0.0
 *
 * Copyright 2013 Twitter, Inc
 * Licensed under the Apache License v2.0
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Designed and built with all the love in the world by @mdo and @fat.
 */

/*Fonts*/

@font-face {
  font-family: 'Open Sans';
  font-style: normal;
  font-weight: 400;
  src: local('Open Sans'), local('OpenSans'), url("//themes.googleusercontent.com/static/fonts/opensans/v6/u-WUoqrET9fUeobQW7jkRT8E0i7KZn-EPnyo3HZu7kw.woff") format('woff');
}

@font-face {
  font-family: 'Open Sans Light';
  font-style: normal;
  font-weight: 300;
  src: local('Open Sans Light'), local('OpenSans-Light'), url("//themes.googleusercontent.com/static/fonts/opensans/v6/DXI1ORHCpsQm3Vp6mXoaTRa1RVmPjeKy21_GQJaLlJI.woff") format('woff');
}

/*! normalize.css v2.1.0 | MIT License | git.io/normalize */

article,
aside,
details,
figcaption,
figure,
footer,
header,
hgroup,
main,
nav,
section,
summary {
  display: block;
}

audio,
canvas,
video {
  display: inline-block;
}

audio:not([controls]) {
  display: none;
  height: 0;
}

[hidden] {
  display: none;
}

html {
  font-family: sans-serif;
  -webkit-text-size-adjust: 100%;
      -ms-text-size-adjust: 100%;
}

body {
  margin: 0;
}

a:focus {
  outline: thin dotted;
}

a:active,
a:hover {
  outline: 0;
}

h1 {
  margin: 0.67em 0;
  font-size: 2em;
}

abbr[title] {
  border-bottom: 1px dotted;
}

b,
strong {
  font-weight: bold;
}

dfn {
  font-style: italic;
}

hr {
  height: 0;
  -moz-box-sizing: content-box;
       box-sizing: content-box;
}

mark {
  color: #000;
  background: #ff0;
}

code,
kbd,
pre,
samp {
  font-family: monospace, serif;
  font-size: 1em;
}

pre {
  white-space: pre-wrap;
}

q {
  quotes: "\201C" "\201D" "\2018" "\2019";
}

small {
  font-size: 80%;
}

sub,
sup {
  position: relative;
  font-size: 75%;
  line-height: 0;
  vertical-align: baseline;
}

sup {
  top: -0.5em;
}

sub {
  bottom: -0.25em;
}

img {
  border: 0;
}

svg:not(:root) {
  overflow: hidden;
}

figure {
  margin: 0;
}

fieldset {
  padding: 0.35em 0.625em 0.75em;
  margin: 0 2px;
  border: 1px solid #c0c0c0;
}

legend {
  padding: 0;
  border: 0;
}

button,
input,
select,
textarea {
  margin: 0;
  font-family: inherit;
  font-size: 100%;
}

button,
input {
  line-height: normal;
}

button,
select {
  text-transform: none;
}

button,
html input[type="button"],
input[type="reset"],
input[type="submit"] {
  cursor: pointer;
  -webkit-appearance: button;
}

button[disabled],
html input[disabled] {
  cursor: default;
}

input[type="checkbox"],
input[type="radio"] {
  padding: 0;
  box-sizing: border-box;
}

input[type="search"] {
  -webkit-box-sizing: content-box;
     -moz-box-sizing: content-box;
          box-sizing: content-box;
  -webkit-appearance: textfield;
}

input[type="search"]::-webkit-search-cancel-button,
input[type="search"]::-webkit-search-decoration {
  -webkit-appearance: none;
}

button::-moz-focus-inner,
input::-moz-focus-inner {
  padding: 0;
  border: 0;
}

textarea {
  overflow: auto;
  vertical-align: top;
}

table {
  border-collapse: collapse;
  border-spacing: 0;
}

@media print {
  * {
    color: #000 !important;
    text-shadow: none !important;
    background: transparent !important;
    box-shadow: none !important;
  }
  a,
  a:visited {
    text-decoration: underline;
  }
  a[href]:after {
    content: " (" attr(href) ")";
  }
  abbr[title]:after {
    content: " (" attr(title) ")";
  }
  .ir a:after,
  a[href^="javascript:"]:after,
  a[href^="#"]:after {
    content: "";
  }
  pre,
  blockquote {
    border: 1px solid #999;
    page-break-inside: avoid;
  }
  thead {
    display: table-header-group;
  }
  tr,
  img {
    page-break-inside: avoid;
  }
  img {
    max-width: 100% !important;
  }
  @page  {
    margin: 0.5cm;
  }
  p,
  h2,
  h3 {
    orphans: 3;
    widows: 3;
  }
  h2,
  h3 {
    page-break-after: avoid;
  }
  .navbar-toggle {
    display: none;
  }
}

* {
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
}

html {
  font-size: 62.5%;
  -webkit-overflow-scrolling: touch;
  -webkit-tap-highlight-color: rgba(0, 0, 0, 0);
}

@media screen and (max-device-width: 480px) {
  html {
    -webkit-text-size-adjust: 100%;
        -ms-text-size-adjust: 100%;
  }
}

body {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 14px;
  line-height: 20px;
  color: #2e3436;
  background-color: #ffffff;
}

input,
button,
select,
textarea {
  font-family: inherit;
  font-size: inherit;
  line-height: inherit;
}

a {
  color: #0068c6;
  text-decoration: none;
}

a:hover,
a:focus {
  color: #00407a;
  text-decoration: underline;
}

a:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

img {
  width: auto\9;
  height: auto;
  max-width: 100%;
  vertical-align: middle;
}

.img-rounded {
  border-radius: 6px;
}

.img-circle {
  border-radius: 500px;
}

body {
  background-image: url("//cdn.kde.org/img/bg.png");
  background-repeat: repeat;
}

p {
  margin: 0 0 10px;
}

.lead {
  margin-bottom: 20px;
  font-size: 21px;
  font-weight: 200;
  line-height: 1.4;
}

small {
  font-size: 85%;
}

strong {
  font-weight: bold;
}

em {
  font-style: italic;
}

cite {
  font-style: normal;
}

.text-muted {
  color: #d3d7cf;
}

a.text-muted:hover,
a.text-muted:focus {
  color: #b9c0b3;
}

.text-warning {
  color: #c38800;
}

a.text-warning:hover,
a.text-warning:focus {
  color: #906500;
}

.text-danger {
  color: #c6001e;
}

a.text-danger:hover,
a.text-danger:focus {
  color: #930016;
}

.text-success {
  color: #759300;
}

a.text-success:hover,
a.text-success:focus {
  color: #4c6000;
}

.text-left {
  text-align: left;
}

.text-right {
  text-align: right;
}

.text-center {
  text-align: center;
}

h1,
h2,
h3,
h4,
h5,
h6,
.h1,
.h2,
.h3,
.h4,
.h5,
.h6 {
  font-family: "Open Sans Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-weight: normal;
  line-height: 20px;
}

h1 small,
h2 small,
h3 small,
h4 small,
h5 small,
h6 small,
.h1 small,
.h2 small,
.h3 small,
.h4 small,
.h5 small,
.h6 small {
  font-weight: normal;
  line-height: 1;
  color: #d3d7cf;
}

h1,
h2,
h3 {
  margin-top: 20px;
  margin-bottom: 10px;
  line-height: 40px;
}

h3 {
  line-height: 30px;
}

h4,
h5,
h6 {
  margin-top: 10px;
  margin-bottom: 10px;
}

h1,
.h1 {
  font-size: 38.5px;
}

h2,
.h2 {
  font-size: 31.5px;
}

h3,
.h3 {
  font-size: 24.5px;
}

h4,
.h4 {
  font-size: 17.5px;
}

h5,
.h5 {
  font-size: 14px;
}

h6,
.h6 {
  font-size: 11.9px;
}

h1 small,
.h1 small {
  font-size: 24.5px;
}

h2 small,
.h2 small {
  font-size: 17.5px;
}

h3 small,
.h3 small {
  font-size: 14px;
}

h4 small,
.h4 small {
  font-size: 14px;
}

.page-header {
  padding-bottom: 9px;
  margin: 40px 0 20px;
  border-bottom: 1px solid #fafafa;
}

ul,
ol {
  padding: 0;
  margin: 0 0 10px 25px;
}

ul ul,
ul ol,
ol ol,
ol ul {
  margin-bottom: 0;
}

li {
  line-height: 20px;
}

.list-unstyled {
  margin-left: 0;
  list-style: none;
}

.list-inline {
  margin-left: 0;
  list-style: none;
}

.list-inline > li {
  display: inline-block;
  padding-right: 5px;
  padding-left: 5px;
}

dl {
  margin-bottom: 20px;
}

dt,
dd {
  line-height: 20px;
}

dt {
  font-weight: bold;
}

dd {
  margin-left: 10px;
}

.dl-horizontal:before,
.dl-horizontal:after {
  display: table;
  content: " ";
}

.dl-horizontal:after {
  clear: both;
}

.dl-horizontal:before,
.dl-horizontal:after {
  display: table;
  content: " ";
}

.dl-horizontal:after {
  clear: both;
}

.dl-horizontal dt {
  float: left;
  width: 160px;
  overflow: hidden;
  clear: left;
  text-align: right;
  text-overflow: ellipsis;
  white-space: nowrap;
}

.dl-horizontal dd {
  margin-left: 180px;
}

hr {
  margin: 20px 0;
  border: 0;
  border-top: 1px solid #fafafa;
  border-bottom: 1px solid #fff;
  border-bottom: 1px solid rgba(255, 255, 255, 0.5);
}

abbr[title],
abbr[data-original-title] {
  cursor: help;
  border-bottom: 1px dotted #d3d7cf;
}

abbr.initialism {
  font-size: 90%;
  text-transform: uppercase;
}

blockquote {
  padding: 0 0 0 15px;
  margin: 0 0 20px;
  border-left: 5px solid #fafafa;
}

blockquote p {
  margin-bottom: 0;
  font-size: 17.5px;
  font-weight: 300;
  line-height: 1.25;
}

blockquote small {
  display: block;
  line-height: 20px;
  color: #d3d7cf;
}

blockquote small:before {
  content: '\2014 \00A0';
}

blockquote.pull-right {
  float: right;
  padding-right: 15px;
  padding-left: 0;
  border-right: 5px solid #fafafa;
  border-left: 0;
}

blockquote.pull-right p,
blockquote.pull-right small {
  text-align: right;
}

blockquote.pull-right small:before {
  content: '';
}

blockquote.pull-right small:after {
  content: '\00A0 \2014';
}

q:before,
q:after,
blockquote:before,
blockquote:after {
  content: "";
}

address {
  display: block;
  margin-bottom: 20px;
  font-style: normal;
  line-height: 20px;
}

h1,
h2,
h3,
h4,
h5,
h6 {
  color: #204a87;
}

h4,
h5,
h6 {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

.lead {
  font-family: "Open Sans Light", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: #204a87;
}

.page-header {
  border-bottom: 1px solid #d3d7cf;
  -webkit-box-shadow: 0 1px 1px #ffffff;
          box-shadow: 0 1px 1px #ffffff;
}

hr {
  height: 1px;
  margin: 20px 0;
  background-color: #dbded8;
  background-image: -webkit-gradient(linear, 0 0, 100% 0, from(#fafafa), color-stop(50%, #d3d7cf), to(#fafafa));
  background-image: -webkit-linear-gradient(left, #fafafa, #d3d7cf 50%, #fafafa);
  background-image: -moz-linear-gradient(left, #fafafa, #d3d7cf 50%, #fafafa);
  background-image: -ms-linear-gradient(left, #fafafa, #d3d7cf 50%, #fafafa);
  background-image: -o-linear-gradient(left, #fafafa, #d3d7cf 50%, #fafafa);
  background-image: linear-gradient(left, #fafafa, #d3d7cf 50%, #fafafa);
  background-repeat: no-repeat;
  border: 0;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#fafafa', endColorstr='#fafafa', GradientType=1);
}

blockquote small {
  color: #9c9c9c;
}

code,
pre {
  padding: 0 3px 2px;
  font-family: Menlo, Monaco, Consolas, "Courier New", monospace;
  font-size: 12px;
  color: #636363;
  border-radius: 4px;
}

code {
  padding: 2px 4px;
  font-size: 90%;
  color: #c7254e;
  white-space: nowrap;
  background-color: #f9f2f4;
}

pre {
  display: block;
  padding: 9.5px;
  margin: 0 0 10px;
  font-size: 13px;
  line-height: 20px;
  word-break: break-all;
  word-wrap: break-word;
  white-space: pre;
  white-space: pre-wrap;
  background-color: #f5f5f5;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
}

pre.prettyprint {
  margin-bottom: 20px;
}

pre code {
  padding: 0;
  color: inherit;
  white-space: pre;
  white-space: pre-wrap;
  background-color: transparent;
  border: 0;
}

.pre-scrollable {
  max-height: 340px;
  overflow-y: scroll;
}

.container {
  margin-right: auto;
  margin-left: auto;
}

.container:before,
.container:after {
  display: table;
  content: " ";
}

.container:after {
  clear: both;
}

.container:before,
.container:after {
  display: table;
  content: " ";
}

.container:after {
  clear: both;
}

.row:before,
.row:after {
  display: table;
  content: " ";
}

.row:after {
  clear: both;
}

.row:before,
.row:after {
  display: table;
  content: " ";
}

.row:after {
  clear: both;
}

.row .row {
  margin-right: -15px;
  margin-left: -15px;
}

[class*="col-span-"],
[class*="col-small-"] {
  position: relative;
  min-height: 1px;
  padding-right: 15px;
  padding-left: 15px;
}

[class*="col-small-"] {
  float: left;
}

.col-small-span-12 {
  width: 100%;
}

.col-small-span-11 {
  width: 91.66666666666666%;
}

.col-small-span-10 {
  width: 83.33333333333334%;
}

.col-small-span-9 {
  width: 75%;
}

.col-small-span-8 {
  width: 66.66666666666666%;
}

.col-small-span-7 {
  width: 58.333333333333336%;
}

.col-small-span-6 {
  width: 50%;
}

.col-small-span-5 {
  width: 41.66666666666667%;
}

.col-small-span-4 {
  width: 33.33333333333333%;
}

.col-small-span-3 {
  width: 25%;
}

.col-small-span-2 {
  width: 16.666666666666664%;
}

.col-small-span-1 {
  width: 8.333333333333332%;
}

@media screen and (min-width: 768px) {
  .container {
    max-width: 728px;
  }
  [class*="col-span-"] {
    float: left;
  }
  .col-span-12 {
    width: 100%;
  }
  .col-span-11 {
    width: 91.66666666666666%;
  }
  .col-span-10 {
    width: 83.33333333333334%;
  }
  .col-span-9 {
    width: 75%;
  }
  .col-span-8 {
    width: 66.66666666666666%;
  }
  .col-span-7 {
    width: 58.333333333333336%;
  }
  .col-span-6 {
    width: 50%;
  }
  .col-span-5 {
    width: 41.66666666666667%;
  }
  .col-span-4 {
    width: 33.33333333333333%;
  }
  .col-span-3 {
    width: 25%;
  }
  .col-span-2 {
    width: 16.666666666666664%;
  }
  .col-span-1 {
    width: 8.333333333333332%;
  }
  .col-offset-12 {
    margin-left: 100%;
  }
  .col-offset-11 {
    margin-left: 91.66666666666666%;
  }
  .col-offset-10 {
    margin-left: 83.33333333333334%;
  }
  .col-offset-9 {
    margin-left: 75%;
  }
  .col-offset-8 {
    margin-left: 66.66666666666666%;
  }
  .col-offset-7 {
    margin-left: 58.333333333333336%;
  }
  .col-offset-6 {
    margin-left: 50%;
  }
  .col-offset-5 {
    margin-left: 41.66666666666667%;
  }
  .col-offset-4 {
    margin-left: 33.33333333333333%;
  }
  .col-offset-3 {
    margin-left: 25%;
  }
  .col-offset-2 {
    margin-left: 16.666666666666664%;
  }
  .col-offset-1 {
    margin-left: 8.333333333333332%;
  }
  .col-push-12 {
    left: 100%;
  }
  .col-push-11 {
    left: 91.66666666666666%;
  }
  .col-push-10 {
    left: 83.33333333333334%;
  }
  .col-push-9 {
    left: 75%;
  }
  .col-push-8 {
    left: 66.66666666666666%;
  }
  .col-push-7 {
    left: 58.333333333333336%;
  }
  .col-push-6 {
    left: 50%;
  }
  .col-push-5 {
    left: 41.66666666666667%;
  }
  .col-push-4 {
    left: 33.33333333333333%;
  }
  .col-push-3 {
    left: 25%;
  }
  .col-push-2 {
    left: 16.666666666666664%;
  }
  .col-push-1 {
    left: 8.333333333333332%;
  }
  .col-pull-12 {
    right: 100%;
  }
  .col-pull-11 {
    right: 91.66666666666666%;
  }
  .col-pull-10 {
    right: 83.33333333333334%;
  }
  .col-pull-9 {
    right: 75%;
  }
  .col-pull-8 {
    right: 66.66666666666666%;
  }
  .col-pull-7 {
    right: 58.333333333333336%;
  }
  .col-pull-6 {
    right: 50%;
  }
  .col-pull-5 {
    right: 41.66666666666667%;
  }
  .col-pull-4 {
    right: 33.33333333333333%;
  }
  .col-pull-3 {
    right: 25%;
  }
  .col-pull-2 {
    right: 16.666666666666664%;
  }
  .col-pull-1 {
    right: 8.333333333333332%;
  }
}

@media screen and (min-width: 992px) {
  .container {
    max-width: 940px;
  }
}

@media screen and (min-width: 1200px) {
  .container {
    max-width: 1170px;
  }
}

[class*="col-span-"].pull-right {
  float: right;
}

table {
  max-width: 100%;
  background-color: transparent;
  border-collapse: collapse;
  border-spacing: 0;
}

th {
  text-align: left;
}

.table {
  width: 100%;
  margin-bottom: 20px;
}

.table th,
.table td {
  padding: 8px;
  line-height: 20px;
  vertical-align: top;
  border-top: 1px solid #dddddd;
}

.table thead th {
  vertical-align: bottom;
}

.table caption + thead tr:first-child th,
.table caption + thead tr:first-child td,
.table colgroup + thead tr:first-child th,
.table colgroup + thead tr:first-child td,
.table thead:first-child tr:first-child th,
.table thead:first-child tr:first-child td {
  border-top: 0;
}

.table tbody + tbody {
  border-top: 2px solid #dddddd;
}

.table .table {
  background-color: #ffffff;
}

.table-condensed th,
.table-condensed td {
  padding: 4px 5px;
}

.table-bordered {
  border: 1px solid #dddddd;
  border-collapse: separate;
  border-left: 0;
  border-radius: 2px;
}

.table-bordered th,
.table-bordered td {
  border-left: 1px solid #dddddd;
}

.table-bordered caption + thead tr:first-child th,
.table-bordered caption + tbody tr:first-child th,
.table-bordered caption + tbody tr:first-child td,
.table-bordered colgroup + thead tr:first-child th,
.table-bordered colgroup + tbody tr:first-child th,
.table-bordered colgroup + tbody tr:first-child td,
.table-bordered thead:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child th,
.table-bordered tbody:first-child tr:first-child td {
  border-top: 0;
}

.table-bordered thead:first-child tr:first-child > th:first-child,
.table-bordered tbody:first-child tr:first-child > td:first-child,
.table-bordered tbody:first-child tr:first-child > th:first-child {
  border-top-left-radius: 2px;
}

.table-bordered thead:first-child tr:first-child > th:last-child,
.table-bordered tbody:first-child tr:first-child > td:last-child,
.table-bordered tbody:first-child tr:first-child > th:last-child {
  border-top-right-radius: 2px;
}

.table-bordered thead:last-child tr:last-child > th:first-child,
.table-bordered tbody:last-child tr:last-child > td:first-child,
.table-bordered tbody:last-child tr:last-child > th:first-child,
.table-bordered tfoot:last-child tr:last-child > td:first-child,
.table-bordered tfoot:last-child tr:last-child > th:first-child {
  border-bottom-left-radius: 2px;
}

.table-bordered thead:last-child tr:last-child > th:last-child,
.table-bordered tbody:last-child tr:last-child > td:last-child,
.table-bordered tbody:last-child tr:last-child > th:last-child,
.table-bordered tfoot:last-child tr:last-child > td:last-child,
.table-bordered tfoot:last-child tr:last-child > th:last-child {
  border-bottom-right-radius: 2px;
}

.table-bordered tfoot + tbody:last-child tr:last-child > td:first-child {
  border-bottom-left-radius: 0;
}

.table-bordered tfoot + tbody:last-child tr:last-child > td:last-child {
  border-bottom-right-radius: 0;
}

.table-bordered caption + thead tr:first-child th:first-child,
.table-bordered caption + tbody tr:first-child td:first-child,
.table-bordered colgroup + thead tr:first-child th:first-child,
.table-bordered colgroup + tbody tr:first-child td:first-child {
  border-top-left-radius: 2px;
}

.table-bordered caption + thead tr:first-child th:last-child,
.table-bordered caption + tbody tr:first-child td:last-child,
.table-bordered colgroup + thead tr:first-child th:last-child,
.table-bordered colgroup + tbody tr:first-child td:last-child {
  border-top-right-radius: 2px;
}

.table-striped > tbody > tr:nth-child(odd) > td,
.table-striped > tbody > tr:nth-child(odd) > th {
  background-color: #f9f9f9;
}

.table-hover > tbody > tr:hover > td,
.table-hover > tbody > tr:hover > th {
  background-color: #f5f5f5;
}

table col[class*="col-span-"] {
  display: table-column;
  float: none;
}

table td[class*="col-span-"],
table th[class*="col-span-"] {
  display: table-cell;
  float: none;
}

.table > tbody > tr > td.success,
.table > tbody > tr > th.success,
.table > tbody > tr.success > td {
  background-color: #f3ffc6;
  border-color: #fbff93;
}

.table > tbody > tr > td.danger,
.table > tbody > tr > th.danger,
.table > tbody > tr.danger > td {
  background-color: #ffc6cf;
  border-color: #ff93b5;
}

.table > tbody > tr > td.warning,
.table > tbody > tr > th.warning,
.table > tbody > tr.warning > td {
  background-color: #ffedc3;
  border-color: #ffcb90;
}

.table-hover > tbody > tr > td.success:hover,
.table-hover > tbody > tr > th.success:hover,
.table-hover > tbody > tr.success:hover > td {
  background-color: #eeffac;
  border-color: #faff7a;
}

.table-hover > tbody > tr > td.danger:hover,
.table-hover > tbody > tr > th.danger:hover,
.table-hover > tbody > tr.danger:hover > td {
  background-color: #ffacb9;
  border-color: #ff7aa4;
}

.table-hover > tbody > tr > td.warning:hover,
.table-hover > tbody > tr > th.warning:hover,
.table-hover > tbody > tr.warning:hover > td {
  background-color: #ffe5a9;
  border-color: #ffbf77;
}

form {
  margin: 0;
}

fieldset {
  padding: 0;
  margin: 0;
  border: 0;
}

legend {
  display: block;
  width: 100%;
  padding: 0;
  margin-bottom: 20px;
  font-size: 21px;
  line-height: 40px;
  color: #636363;
  border: 0;
  border-bottom: 1px solid #e5e5e5;
}

label {
  display: inline-block;
  margin-bottom: 5px;
  font-weight: bold;
}

select,
textarea,
input[type="text"],
input[type="password"],
input[type="datetime"],
input[type="datetime-local"],
input[type="date"],
input[type="month"],
input[type="time"],
input[type="week"],
input[type="number"],
input[type="email"],
input[type="url"],
input[type="search"],
input[type="tel"],
input[type="color"] {
  display: inline-block;
  min-height: 34px;
  padding: 6px 9px;
  font-size: 14px;
  line-height: 20px;
  color: #9c9c9c;
  vertical-align: middle;
  background-color: #ffffff;
  border: 1px solid #cccccc;
  border-radius: 2px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
  -webkit-transition: border linear 0.2s, box-shadow linear 0.2s;
     -moz-transition: border linear 0.2s, box-shadow linear 0.2s;
       -o-transition: border linear 0.2s, box-shadow linear 0.2s;
          transition: border linear 0.2s, box-shadow linear 0.2s;
}

input,
select,
textarea {
  width: 100%;
}

input[type="file"],
input[type="image"],
input[type="submit"],
input[type="reset"],
input[type="button"],
input[type="radio"],
input[type="checkbox"] {
  width: auto;
}

textarea {
  height: auto;
}

textarea:focus,
input[type="text"]:focus,
input[type="password"]:focus,
input[type="datetime"]:focus,
input[type="datetime-local"]:focus,
input[type="date"]:focus,
input[type="month"]:focus,
input[type="time"]:focus,
input[type="week"]:focus,
input[type="number"]:focus,
input[type="email"]:focus,
input[type="url"]:focus,
input[type="search"]:focus,
input[type="tel"]:focus,
input[type="color"]:focus {
  border-color: rgba(82, 168, 236, 0.8);
  outline: 0;
  outline: thin dotted \9;
  /* IE6-9 */

  -webkit-box-shadow: 0 0 8px rgba(82, 168, 236, 0.6);
          box-shadow: 0 0 8px rgba(82, 168, 236, 0.6);
}

input[type="radio"],
input[type="checkbox"] {
  margin: 4px 0 0;
  margin-top: 1px \9;
  /* IE8-9 */

  line-height: normal;
}

select,
input[type="file"] {
  height: 34px;
  /* In IE7, the height of the select element cannot be changed by height, only font-size. TODO: Check if this is still needed when dropping IE7 support */

  line-height: 34px;
}

select[multiple],
select[size] {
  height: auto;
}

select:focus,
input[type="file"]:focus,
input[type="radio"]:focus,
input[type="checkbox"]:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

input:-moz-placeholder,
textarea:-moz-placeholder {
  color: #d3d7cf;
}

input::-moz-placeholder,
textarea::-moz-placeholder {
  color: #d3d7cf;
}

input:-ms-input-placeholder,
textarea:-ms-input-placeholder {
  color: #d3d7cf;
}

input::-webkit-input-placeholder,
textarea::-webkit-input-placeholder {
  color: #d3d7cf;
}

.radio,
.checkbox {
  display: block;
  min-height: 20px;
  padding-left: 20px;
  margin-bottom: 10px;
}

.radio label,
.checkbox label {
  display: inline;
  margin-bottom: 0;
  font-weight: normal;
}

.radio input[type="radio"],
.radio-inline input[type="radio"],
.checkbox input[type="checkbox"],
.checkbox-inline input[type="checkbox"] {
  float: left;
  margin-left: -20px;
}

.radio + .radio,
.checkbox + .checkbox {
  margin-top: -5px;
}

.controls > .radio:first-child,
.controls > .checkbox:first-child {
  padding-top: 5px;
}

.radio-inline,
.checkbox-inline {
  display: inline-block;
  padding-top: 5px;
  padding-left: 20px;
  margin-bottom: 0;
  font-weight: normal;
  vertical-align: middle;
}

.radio-inline + .radio-inline,
.checkbox-inline + .checkbox-inline {
  margin-top: 0;
  margin-left: 10px;
}

select.input-large,
textarea.input-large,
input[type="text"].input-large,
input[type="password"].input-large,
input[type="datetime"].input-large,
input[type="datetime-local"].input-large,
input[type="date"].input-large,
input[type="month"].input-large,
input[type="time"].input-large,
input[type="week"].input-large,
input[type="number"].input-large,
input[type="email"].input-large,
input[type="url"].input-large,
input[type="search"].input-large,
input[type="tel"].input-large,
input[type="color"].input-large {
  padding: 11px 14px;
  font-size: 17.5px;
  border-radius: 3px;
}

select.input-small,
textarea.input-small,
input[type="text"].input-small,
input[type="password"].input-small,
input[type="datetime"].input-small,
input[type="datetime-local"].input-small,
input[type="date"].input-small,
input[type="month"].input-small,
input[type="time"].input-small,
input[type="week"].input-small,
input[type="number"].input-small,
input[type="email"].input-small,
input[type="url"].input-small,
input[type="search"].input-small,
input[type="tel"].input-small,
input[type="color"].input-small {
  min-height: 26px;
  padding: 2px 10px;
  font-size: 11.9px;
  border-radius: 1px;
}

input[class*="span"],
select[class*="span"],
textarea[class*="span"] {
  float: none;
  margin-right: 0;
  margin-left: 0;
}

.input-append input[class*="span"],
.input-prepend input[class*="span"] {
  display: inline-block;
}

input[class*="span"],
select[class*="span"],
textarea[class*="span"] {
  height: 34px;
}

input[disabled],
select[disabled],
textarea[disabled],
input[readonly],
select[readonly],
textarea[readonly],
fieldset[disabled] input,
fieldset[disabled] select,
fieldset[disabled] textarea {
  cursor: not-allowed;
  background-color: #fafafa;
}

input[type="radio"][disabled],
input[type="checkbox"][disabled],
input[type="radio"][readonly],
input[type="checkbox"][readonly],
fieldset[disabled] input[type="radio"],
fieldset[disabled] input[type="checkbox"] {
  background-color: transparent;
}

.has-warning .control-label {
  color: #c38800;
}

.has-warning .input-with-feedback {
  padding-right: 32px;
  border-color: #c38800;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-warning .input-with-feedback:focus {
  border-color: #906500;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ffbf2a;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ffbf2a;
}

.has-error .control-label {
  color: #c6001e;
}

.has-error .input-with-feedback {
  padding-right: 32px;
  border-color: #c6001e;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-error .input-with-feedback:focus {
  border-color: #930016;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff2d4d;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #ff2d4d;
}

.has-success .control-label {
  color: #759300;
}

.has-success .input-with-feedback {
  padding-right: 32px;
  border-color: #759300;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075);
}

.has-success .input-with-feedback:focus {
  border-color: #4c6000;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c5f900;
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.075), 0 0 6px #c5f900;
}

input:focus:invalid,
textarea:focus:invalid,
select:focus:invalid {
  color: #b94a48;
  border-color: #ee5f5b;
}

input:focus:invalid:focus,
textarea:focus:invalid:focus,
select:focus:invalid:focus {
  border-color: #e9322d;
  -webkit-box-shadow: 0 0 6px #f8b9b7;
          box-shadow: 0 0 6px #f8b9b7;
}

.form-actions {
  padding: 19px 20px 20px;
  margin-top: 20px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border-top: 1px solid #e5e5e5;
}

.form-actions:before,
.form-actions:after {
  display: table;
  content: " ";
}

.form-actions:after {
  clear: both;
}

.form-actions:before,
.form-actions:after {
  display: table;
  content: " ";
}

.form-actions:after {
  clear: both;
}

.help-block,
.help-inline {
  color: #69767b;
}

.help-block {
  display: block;
  margin-bottom: 10px;
}

.help-inline {
  display: inline-block;
  padding-left: 5px;
  vertical-align: middle;
}

.input-group {
  display: table;
}

.input-group[class*="span"] {
  float: none;
  padding: 0;
}

.input-group input,
.input-group select {
  width: 100%;
}

.input-group-addon,
.input-group-btn,
.input-group input {
  display: table-cell;
  margin: 0;
  border-radius: 0;
}

.input-group-addon.input-small,
.input-group-btn.input-small,
.input-group input.input-small {
  border-radius: 0;
}

.input-group-addon.input-large,
.input-group-btn.input-large,
.input-group input.input-large {
  border-radius: 0;
}

.input-group-addon,
.input-group-btn {
  width: 1%;
  vertical-align: middle;
}

.input-group-addon {
  padding: 6px 8px;
  font-size: 14px;
  font-weight: normal;
  line-height: 20px;
  text-align: center;
  text-shadow: 0 1px 0 #fff;
  background-color: #fafafa;
  border: 1px solid #ccc;
  -webkit-box-sizing: border-box;
     -moz-box-sizing: border-box;
          box-sizing: border-box;
}

.input-group-addon.input-small {
  padding: 2px 10px;
  font-size: 11.9px;
}

.input-group-addon.input-large {
  padding: 11px 14px;
  font-size: 17.5px;
}

.input-group input:first-child,
.input-group-addon:first-child {
  border-bottom-left-radius: 2px;
  border-top-left-radius: 2px;
}

.input-group input:first-child.input-small,
.input-group-addon:first-child.input-small {
  border-bottom-left-radius: 1px;
  border-top-left-radius: 1px;
}

.input-group input:first-child.input-large,
.input-group-addon:first-child.input-large {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 3px;
}

.input-group-addon:first-child {
  border-right: 0;
}

.input-group input:last-child,
.input-group-addon:last-child {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

.input-group input:last-child.input-small,
.input-group-addon:last-child.input-small {
  border-top-right-radius: 1px;
  border-bottom-right-radius: 1px;
}

.input-group input:last-child.input-large,
.input-group-addon:last-child.input-large {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

.input-group-addon:last-child {
  border-left: 0;
}

.input-group-btn {
  position: relative;
  white-space: nowrap;
}

.input-group-btn > .btn {
  position: relative;
  float: left;
  border-radius: 0;
}

.input-group-btn > .btn + .btn {
  margin-left: -1px;
}

.input-group-btn > .btn:hover,
.input-group-btn > .btn:active {
  z-index: 2;
}

.input-group-btn:first-child > .btn:first-child,
.input-group-btn:first-child > .dropdown-toggle:first-child {
  border-bottom-left-radius: 2px;
  border-top-left-radius: 2px;
}

.input-group-btn:first-child > .btn:first-child.btn-large,
.input-group-btn:first-child > .dropdown-toggle:first-child.btn-large {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 3px;
}

.input-group-btn:first-child > .btn:first-child.btn-small,
.input-group-btn:first-child > .dropdown-toggle:first-child.btn-small {
  border-bottom-left-radius: 1px;
  border-top-left-radius: 1px;
}

.input-group-btn:last-child > .btn:last-child,
.input-group-btn:last-child > .dropdown-toggle {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

.input-group-btn:last-child > .btn:last-child.btn-large,
.input-group-btn:last-child > .dropdown-toggle.btn-large {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

.input-group-btn:last-child > .btn:last-child.btn-small,
.input-group-btn:last-child > .dropdown-toggle.btn-small {
  border-top-right-radius: 1px;
  border-bottom-right-radius: 1px;
}

@media screen and (min-width: 768px) {
  .form-horizontal .control-group {
    position: relative;
    margin-bottom: 20px;
  }
  .form-horizontal .control-group:before,
  .form-horizontal .control-group:after {
    display: table;
    content: " ";
  }
  .form-horizontal .control-group:after {
    clear: both;
  }
  .form-horizontal .control-group:before,
  .form-horizontal .control-group:after {
    display: table;
    content: " ";
  }
  .form-horizontal .control-group:after {
    clear: both;
  }
  .form-horizontal .control-group input,
  .form-horizontal .control-group select,
  .form-horizontal .control-group textarea {
    margin-bottom: 0;
  }
  .form-horizontal .control-group > .control-label {
    float: left;
    width: 160px;
    padding-top: 6px;
    text-align: right;
  }
  .form-horizontal .control-group > .controls {
    margin-left: 180px;
  }
  .form-horizontal .form-actions {
    padding-left: 180px;
  }
}

.btn {
  display: inline-block;
  padding: 6px 12px;
  margin-bottom: 0;
  font-size: 14px;
  font-weight: 500;
  line-height: 20px;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  cursor: pointer;
  border: 1px solid #a7a9aa;
  border-radius: 2px;
}

.btn:focus {
  outline: thin dotted #333;
  outline: 5px auto -webkit-focus-ring-color;
  outline-offset: -2px;
}

.btn:hover,
.btn:focus {
  color: #fff;
  text-decoration: none;
}

.btn:active,
.btn.active {
  background-image: none;
  outline: 0;
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}

.btn.disabled,
.btn[disabled],
fieldset[disabled] .btn {
  pointer-events: none;
  cursor: default;
  opacity: 0.65;
  filter: alpha(opacity=65);
  -webkit-box-shadow: none;
          box-shadow: none;
}

.btn-large {
  padding: 11px 14px;
  font-size: 17.5px;
  border-radius: 3px;
}

.btn-small {
  padding: 2px 10px;
  font-size: 11.9px;
  border-radius: 1px;
}

.btn-mini {
  padding: 0 6px;
  font-size: 10.5px;
  border-radius: 1px;
}

.btn-block {
  display: block;
  width: 100%;
  padding-right: 0;
  padding-left: 0;
}

.btn-block + .btn-block {
  margin-top: 5px;
}

input[type="submit"].btn-block,
input[type="reset"].btn-block,
input[type="button"].btn-block {
  width: 100%;
}

.btn {
  color: #ffffff;
  background-color: #a7a9aa;
  border-color: #a7a9aa;
}

.btn:hover,
.btn:focus,
.btn:active,
.btn.active {
  background-color: #9a9c9d;
  border-color: #8d9091;
}

.btn.disabled:hover,
.btn[disabled]:hover,
fieldset[disabled] .btn:hover,
.btn.disabled:focus,
.btn[disabled]:focus,
fieldset[disabled] .btn:focus,
.btn.disabled:active,
.btn[disabled]:active,
fieldset[disabled] .btn:active,
.btn.disabled.active,
.btn[disabled].active,
fieldset[disabled] .btn.active {
  background-color: #a7a9aa;
  border-color: #a7a9aa;
}

.btn-primary {
  background-color: #0068c6;
  border-color: #0068c6;
}

.btn-primary:hover,
.btn-primary:focus,
.btn-primary:active,
.btn-primary.active {
  background-color: #005bad;
  border-color: #004d93;
}

.btn-primary.disabled:hover,
.btn-primary[disabled]:hover,
fieldset[disabled] .btn-primary:hover,
.btn-primary.disabled:focus,
.btn-primary[disabled]:focus,
fieldset[disabled] .btn-primary:focus,
.btn-primary.disabled:active,
.btn-primary[disabled]:active,
fieldset[disabled] .btn-primary:active,
.btn-primary.disabled.active,
.btn-primary[disabled].active,
fieldset[disabled] .btn-primary.active {
  background-color: #0068c6;
  border-color: #0068c6;
}

.btn-warning {
  background-color: #f6ac00;
  border-color: #f6ac00;
}

.btn-warning:hover,
.btn-warning:focus,
.btn-warning:active,
.btn-warning.active {
  background-color: #dd9a00;
  border-color: #c38800;
}

.btn-warning.disabled:hover,
.btn-warning[disabled]:hover,
fieldset[disabled] .btn-warning:hover,
.btn-warning.disabled:focus,
.btn-warning[disabled]:focus,
fieldset[disabled] .btn-warning:focus,
.btn-warning.disabled:active,
.btn-warning[disabled]:active,
fieldset[disabled] .btn-warning:active,
.btn-warning.disabled.active,
.btn-warning[disabled].active,
fieldset[disabled] .btn-warning.active {
  background-color: #f6ac00;
  border-color: #f6ac00;
}

.btn-danger {
  background-color: #c6001e;
  border-color: #c6001e;
}

.btn-danger:hover,
.btn-danger:focus,
.btn-danger:active,
.btn-danger.active {
  background-color: #ad001a;
  border-color: #930016;
}

.btn-danger.disabled:hover,
.btn-danger[disabled]:hover,
fieldset[disabled] .btn-danger:hover,
.btn-danger.disabled:focus,
.btn-danger[disabled]:focus,
fieldset[disabled] .btn-danger:focus,
.btn-danger.disabled:active,
.btn-danger[disabled]:active,
fieldset[disabled] .btn-danger:active,
.btn-danger.disabled.active,
.btn-danger[disabled].active,
fieldset[disabled] .btn-danger.active {
  background-color: #c6001e;
  border-color: #c6001e;
}

.btn-success {
  background-color: #9dc600;
  border-color: #9dc600;
}

.btn-success:hover,
.btn-success:focus,
.btn-success:active,
.btn-success.active {
  background-color: #89ad00;
  border-color: #759300;
}

.btn-success.disabled:hover,
.btn-success[disabled]:hover,
fieldset[disabled] .btn-success:hover,
.btn-success.disabled:focus,
.btn-success[disabled]:focus,
fieldset[disabled] .btn-success:focus,
.btn-success.disabled:active,
.btn-success[disabled]:active,
fieldset[disabled] .btn-success:active,
.btn-success.disabled.active,
.btn-success[disabled].active,
fieldset[disabled] .btn-success.active {
  background-color: #9dc600;
  border-color: #9dc600;
}

.btn-info {
  background-color: #0068c6;
  border-color: #0068c6;
}

.btn-info:hover,
.btn-info:focus,
.btn-info:active,
.btn-info.active {
  background-color: #005bad;
  border-color: #004d93;
}

.btn-info.disabled:hover,
.btn-info[disabled]:hover,
fieldset[disabled] .btn-info:hover,
.btn-info.disabled:focus,
.btn-info[disabled]:focus,
fieldset[disabled] .btn-info:focus,
.btn-info.disabled:active,
.btn-info[disabled]:active,
fieldset[disabled] .btn-info:active,
.btn-info.disabled.active,
.btn-info[disabled].active,
fieldset[disabled] .btn-info.active {
  background-color: #0068c6;
  border-color: #0068c6;
}

.btn-link,
.btn-link:active,
.btn-link[disabled],
fieldset[disabled] .btn-link {
  background-color: transparent;
  background-image: none;
  -webkit-box-shadow: none;
          box-shadow: none;
}

.btn-link,
.btn-link:hover,
.btn-link:focus,
.btn-link:active {
  border-color: transparent;
}

.btn-link {
  font-weight: normal;
  color: #0068c6;
  cursor: pointer;
  border-radius: 0;
}

.btn-link:hover,
.btn-link:focus {
  color: #00407a;
  text-decoration: underline;
  background-color: transparent;
}

.btn-link[disabled]:hover,
fieldset[disabled] .btn-link:hover,
.btn-link[disabled]:focus,
fieldset[disabled] .btn-link:focus {
  color: #636363;
  text-decoration: none;
}

.btn {
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.btn-group {
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.btn-group .btn {
  -webkit-box-shadow: none;
          box-shadow: none;
}

.fade {
  opacity: 0;
  -webkit-transition: opacity 0.15s linear;
     -moz-transition: opacity 0.15s linear;
       -o-transition: opacity 0.15s linear;
          transition: opacity 0.15s linear;
}

.fade.in {
  opacity: 1;
}

/*.collapse {
  position: relative;
  height: 0;
  overflow: hidden;
  .transition(height .35s ease);
  &.in {
    height: auto;
  }
}*/

.collapse {
  position: relative;
  height: 0;
  overflow: hidden;
  -webkit-transition: height 0.35s ease;
     -moz-transition: height 0.35s ease;
       -o-transition: height 0.35s ease;
          transition: height 0.35s ease;
}

.collapse.in {
  height: auto;
}

.dropup,
.dropdown {
  position: relative;
}

.dropdown-toggle:active,
.open .dropdown-toggle {
  outline: 0;
}

.caret {
  display: inline-block;
  width: 0;
  height: 0;
  vertical-align: top;
  border-top: 4px solid #000;
  border-right: 4px solid transparent;
  border-left: 4px solid transparent;
  content: "";
}

.dropdown .caret {
  margin-top: 8px;
  margin-left: 2px;
}

.dropdown-menu {
  position: absolute;
  top: 100%;
  left: 0;
  z-index: 1000;
  display: none;
  float: left;
  min-width: 160px;
  padding: 5px 0;
  margin: 2px 0 0;
  list-style: none;
  background-color: #ffffff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.15);
  border-radius: 2px;
  -webkit-box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
          box-shadow: 0 6px 12px rgba(0, 0, 0, 0.175);
  -webkit-background-clip: padding-box;
     -moz-background-clip: padding-box;
          background-clip: padding-box;
}

.dropdown-menu.pull-right {
  right: 0;
  left: auto;
}

.dropdown-menu .divider {
  height: 2px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
  border-bottom: 1px solid #ffffff;
}

.dropdown-menu > li > a {
  display: block;
  padding: 3px 20px;
  clear: both;
  font-weight: normal;
  line-height: 20px;
  color: #636363;
}

.dropdown-menu > li > a:hover,
.dropdown-menu > li > a:focus,
.dropdown-submenu:hover > a,
.dropdown-submenu:focus > a {
  color: #ffffff;
  text-decoration: none;
  background-color: #005bad;
  background-image: -moz-linear-gradient(top, #0068c6, #005bad);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0068c6), to(#005bad));
  background-image: -webkit-linear-gradient(top, #0068c6, #005bad);
  background-image: -o-linear-gradient(top, #0068c6, #005bad);
  background-image: linear-gradient(to bottom, #0068c6, #005bad);
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff0068c6', endColorstr='#ff005bad', GradientType=0);
}

.dropdown-menu > .active > a,
.dropdown-menu > .active > a:hover,
.dropdown-menu > .active > a:focus {
  color: #ffffff;
  text-decoration: none;
  background-color: #005bad;
  background-image: -moz-linear-gradient(top, #0068c6, #005bad);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#0068c6), to(#005bad));
  background-image: -webkit-linear-gradient(top, #0068c6, #005bad);
  background-image: -o-linear-gradient(top, #0068c6, #005bad);
  background-image: linear-gradient(to bottom, #0068c6, #005bad);
  background-repeat: repeat-x;
  outline: 0;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff0068c6', endColorstr='#ff005bad', GradientType=0);
}

.dropdown-menu > .disabled > a,
.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  color: #d3d7cf;
}

.dropdown-menu > .disabled > a:hover,
.dropdown-menu > .disabled > a:focus {
  text-decoration: none;
  cursor: default;
  background-color: transparent;
  background-image: none;
  filter: progid:DXImageTransform.Microsoft.gradient(enabled=false);
}

.open > .dropdown-menu {
  display: block;
}

.pull-right > .dropdown-menu {
  right: 0;
  left: auto;
}

.dropup .caret,
.navbar-fixed-bottom .dropdown .caret {
  border-top: 0;
  border-bottom: 4px solid #000;
  content: "";
}

.dropup .dropdown-menu,
.navbar-fixed-bottom .dropdown .dropdown-menu {
  top: auto;
  bottom: 100%;
  margin-bottom: 1px;
}

.dropdown-submenu {
  position: relative;
}

.dropdown-submenu > .dropdown-menu {
  top: 0;
  left: 100%;
  margin-top: -6px;
  margin-left: -1px;
  border-top-left-radius: 0;
}

.dropdown-submenu:hover > .dropdown-menu {
  display: block;
}

.dropup .dropdown-submenu > .dropdown-menu {
  top: auto;
  bottom: 0;
  margin-top: 0;
  margin-bottom: -2px;
  border-bottom-left-radius: 0;
}

.dropdown-submenu > a:after {
  display: block;
  float: right;
  width: 0;
  height: 0;
  margin-top: 5px;
  margin-right: -10px;
  border-color: transparent;
  border-left-color: #cccccc;
  border-style: solid;
  border-width: 5px 0 5px 5px;
  content: " ";
}

.dropdown-submenu:hover > a:after {
  border-left-color: #ffffff;
}

.dropdown-submenu.pull-left {
  float: none;
}

.dropdown-submenu.pull-left > .dropdown-menu {
  left: -100%;
  margin-left: 10px;
  border-top-right-radius: 0;
}

.dropdown .dropdown-menu .nav-header {
  padding-right: 20px;
  padding-left: 20px;
}

.typeahead {
  z-index: 1051;
}

.list-group {
  margin: 0 0 20px;
  background-color: #ffffff;
}

.list-group-item {
  position: relative;
  display: block;
  padding: 10px 30px 10px 15px;
  margin-bottom: -1px;
  border: 1px solid #dddddd;
}

.list-group-item:first-child {
  border-top-right-radius: 2px;
  border-top-left-radius: 2px;
}

.list-group-item:last-child {
  margin-bottom: 0;
  border-bottom-right-radius: 2px;
  border-bottom-left-radius: 2px;
}

.list-group-item-heading {
  margin-top: 0;
  margin-bottom: 5px;
}

.list-group-item-text {
  margin-bottom: 0;
  line-height: 1.3;
}

a.list-group-item .list-group-item-heading {
  color: #333;
}

a.list-group-item .list-group-item-text {
  color: #555;
}

a.list-group-item:hover,
a.list-group-item:focus {
  text-decoration: none;
  background-color: #f5f5f5;
}

a.list-group-item.active {
  z-index: 2;
  color: #ffffff;
  background-color: #0068c6;
  border-color: #0068c6;
}

a.list-group-item.active .list-group-item-heading {
  color: inherit;
}

a.list-group-item.active .list-group-item-text {
  color: #93ccff;
}

.list-group-item > .badge,
.list-group-item > .glyphicon-chevron-right {
  float: right;
  margin-right: -15px;
}

.list-group-item > .glyphicon-chevron-right {
  margin-right: -15px;
}

.list-group-item > .glyphicon + .badge {
  margin-right: 5px;
}

.panel {
  padding: 15px;
  margin-bottom: 20px;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-radius: 2px;
  -webkit-box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
          box-shadow: 0 1px 1px rgba(0, 0, 0, 0.05);
}

.panel-heading {
  padding: 10px 15px;
  margin: -15px -15px 15px;
  font-size: 17.5px;
  font-weight: 500;
  background-color: #f5f5f5;
  border-bottom: 1px solid #dddddd;
  border-top-right-radius: 1px;
  border-top-left-radius: 1px;
}

.panel-primary {
  border-color: #0068c6;
}

.panel-primary .panel-heading {
  color: #ffffff;
  background-color: #0068c6;
  border-color: #0068c6;
}

.panel-success {
  border-color: #fbff93;
}

.panel-success .panel-heading {
  color: #759300;
  background-color: #f3ffc6;
  border-color: #fbff93;
}

.panel-warning {
  border-color: #ffcb90;
}

.panel-warning .panel-heading {
  color: #c38800;
  background-color: #ffedc3;
  border-color: #ffcb90;
}

.panel-danger {
  border-color: #ff93b5;
}

.panel-danger .panel-heading {
  color: #c6001e;
  background-color: #ffc6cf;
  border-color: #ff93b5;
}

.panel-info {
  border-color: #93deff;
}

.panel-info .panel-heading {
  color: #0068c6;
  background-color: #c6e4ff;
  border-color: #93deff;
}

.list-group-flush {
  margin: 15px -15px -15px;
}

.list-group-flush .list-group-item {
  border-width: 1px 0;
}

.list-group-flush .list-group-item:first-child {
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

.list-group-flush .list-group-item:last-child {
  border-bottom: 0;
}

.panel {
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.panel .panel-heading {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
}

.well {
  min-height: 20px;
  padding: 19px;
  margin-bottom: 20px;
  background-color: #f5f5f5;
  border: 1px solid #e3e3e3;
  border-radius: 2px;
  -webkit-box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
          box-shadow: inset 0 1px 1px rgba(0, 0, 0, 0.05);
}

.well blockquote {
  border-color: #ddd;
  border-color: rgba(0, 0, 0, 0.15);
}

.well-large {
  padding: 24px;
  border-radius: 3px;
}

.well-small {
  padding: 9px;
  border-radius: 1px;
}

.well {
  background-color: rgba(245, 245, 245, 0.75);
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.well blockquote {
  border-color: #d3d7cf;
  border-color: rgba(0, 0, 0, 0.15);
}

.close {
  float: right;
  font-size: 20px;
  font-weight: bold;
  line-height: 20px;
  color: #000;
  text-shadow: 0 1px 0 #ffffff;
  opacity: 0.2;
  filter: alpha(opacity=20);
}

.close:hover,
.close:focus {
  color: #000;
  text-decoration: none;
  cursor: pointer;
  opacity: 0.5;
  filter: alpha(opacity=50);
}

button.close {
  padding: 0;
  cursor: pointer;
  background: transparent;
  border: 0;
  -webkit-appearance: none;
}

.nav {
  padding-left: 0;
  margin-bottom: 0;
  margin-left: 0;
  list-style: none;
}

.nav:before,
.nav:after {
  display: table;
  content: " ";
}

.nav:after {
  clear: both;
}

.nav:before,
.nav:after {
  display: table;
  content: " ";
}

.nav:after {
  clear: both;
}

.nav > li {
  display: block;
}

.nav > li > a {
  position: relative;
  display: block;
  padding: 10px 15px;
}

.nav > li > a:hover,
.nav > li > a:focus {
  text-decoration: none;
  background-color: #fafafa;
}

.nav > .pull-right {
  float: right;
}

.nav-tabs {
  border-bottom: 1px solid #ddd;
}

.nav-tabs > li {
  float: left;
  margin-bottom: -1px;
}

.nav-tabs > li > a {
  margin-right: 2px;
  line-height: 20px;
  border: 1px solid transparent;
  border-radius: 2px 2px 0 0;
}

.nav-tabs > li > a:hover {
  border-color: #fafafa #fafafa #dddddd;
}

.nav-tabs > .active > a,
.nav-tabs > .active > a:hover,
.nav-tabs > .active > a:focus {
  color: #9c9c9c;
  cursor: default;
  background-color: #ffffff;
  border: 1px solid #ddd;
  border-bottom-color: transparent;
}

.nav-pills > li {
  float: left;
}

.nav-pills > li > a {
  border-radius: 5px;
}

.nav-pills > li + li > a {
  margin-left: 2px;
}

.nav-pills > .active > a,
.nav-pills > .active > a:hover,
.nav-pills > .active > a:focus {
  color: #fff;
  background-color: #0068c6;
}

.nav-stacked > li {
  float: none;
}

.nav-stacked > li + li > a {
  margin-top: 2px;
  margin-left: 0;
}

.nav-justified {
  width: 100%;
}

.nav-justified > li {
  display: table-cell;
  float: none;
  width: 1%;
  text-align: center;
}

.nav-justified.nav-tabs {
  border-bottom: 0;
}

.nav-justified.nav-tabs > li > a {
  border-bottom: 1px solid #ddd;
}

.nav-justified.nav-tabs > .active > a {
  border-bottom-color: #ffffff;
}

.nav-justified > li > a {
  margin-right: 0;
}

.nav > .disabled > a {
  color: #d3d7cf;
}

.nav > .disabled > a:hover,
.nav > .disabled > a:focus {
  color: #d3d7cf;
  text-decoration: none;
  cursor: default;
  background-color: transparent;
}

.nav-header {
  display: block;
  padding: 3px 15px;
  font-size: 11px;
  font-weight: bold;
  line-height: 20px;
  color: #d3d7cf;
  text-shadow: 0 1px 0 rgba(255, 255, 255, 0.5);
  text-transform: uppercase;
}

.nav li + .nav-header {
  margin-top: 9px;
}

.nav .divider {
  height: 2px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e5e5e5;
  border-bottom: 1px solid #ffffff;
}

.tabbable:before,
.tabbable:after {
  display: table;
  content: " ";
}

.tabbable:after {
  clear: both;
}

.tabbable:before,
.tabbable:after {
  display: table;
  content: " ";
}

.tabbable:after {
  clear: both;
}

.tab-content > .tab-pane,
.pill-content > .pill-pane {
  display: none;
}

.tab-content > .active,
.pill-content > .active {
  display: block;
}

/*
// Prevent IE8 from misplacing imgs
// See https://github.com/h5bp/html5-boilerplate/issues/984#issuecomment-3985989
.nav > li > a > img {
  max-width: none;
}

// Dropdowns
// -------------------------

.nav-tabs .dropdown-menu {
  // Remove the top rounded corners here since there is a hard edge above the menu
  .border-top-radius(0);
}

// Default dropdown links
// -------------------------
// Make carets use linkColor to start
.nav .dropdown-toggle .caret {
  border-top-color: @link-color;
  border-bottom-color: @link-color;
  margin-top: 8px;
}
.nav .dropdown-toggle:hover .caret {
  border-top-color: @link-hover-color;
  border-bottom-color: @link-hover-color;
}

// Active dropdown links
// -------------------------
.nav .active .dropdown-toggle .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
}
.nav-tabs .active .dropdown-toggle .caret {
  border-top-color: @gray;
  border-bottom-color: @gray;
}

// Active:hover dropdown links
// -------------------------
.nav > .dropdown.active > a:hover {
  cursor: pointer;
}

// Open dropdowns
// -------------------------
.nav-tabs .open .dropdown-toggle,
.nav-pills .open .dropdown-toggle,
.nav > li.dropdown.open.active > a:hover {
  color: #fff;
  background-color: @grayLight;
  border-color: @grayLight;
}
.nav li.dropdown.open .caret,
.nav li.dropdown.open.active .caret,
.nav li.dropdown.open a:hover .caret {
  border-top-color: #fff;
  border-bottom-color: #fff;
  .opacity(1);
}

// Dropdowns in stacked tabs
.tabs-stacked .open > a:hover {
  border-color: @grayLight;
}

*/

.navbar {
  position: relative;
  padding: 10px 15px;
  background-color: #eeeeee;
  border-radius: 2px;
}

.navbar:before,
.navbar:after {
  display: table;
  content: " ";
}

.navbar:after {
  clear: both;
}

.navbar:before,
.navbar:after {
  display: table;
  content: " ";
}

.navbar:after {
  clear: both;
}

.navbar .nav {
  margin-top: 15px;
}

.navbar .nav > li > a {
  padding-top: 15px;
  padding-bottom: 15px;
  line-height: 20px;
  color: #777777;
}

.navbar .nav > li > a:hover,
.navbar .nav > li > a:focus {
  color: #333333;
  background-color: transparent;
}

.navbar .nav > .active > a,
.navbar .nav > .active > a:hover,
.navbar .nav > .active > a:focus {
  color: #555555;
  background-color: #d5d5d5;
}

.navbar .nav > .disabled > a,
.navbar .nav > .disabled > a:hover,
.navbar .nav > .disabled > a:focus {
  color: #cccccc;
  background-color: transparent;
}

.navbar-static-top {
  border-radius: 0;
}

.navbar-fixed-top,
.navbar-fixed-bottom {
  position: fixed;
  right: 0;
  left: 0;
  z-index: 1030;
  border-radius: 0;
}

.navbar-fixed-top {
  top: 0;
}

.navbar-fixed-bottom {
  bottom: 0;
}

.navbar-brand {
  display: block;
  max-width: 200px;
  padding: 7px 15px;
  margin-right: auto;
  margin-left: auto;
  font-size: 18px;
  font-weight: 500;
  line-height: 20px;
  color: #777777;
  text-align: center;
}

.navbar-brand:hover,
.navbar-brand:focus {
  color: #5e5e5e;
  text-decoration: none;
  background-color: transparent;
}

.navbar-toggle {
  position: absolute;
  top: 10px;
  right: 10px;
  padding: 8px 12px;
  background-color: transparent;
  border: 1px solid #ddd;
  border-radius: 4px;
}

.navbar-toggle:hover,
.navbar-toggle:focus {
  background-color: #ddd;
}

.navbar-toggle .icon-bar {
  display: block;
  width: 22px;
  height: 2px;
  background-color: #ccc;
  border-radius: 1px;
}

.navbar-toggle .icon-bar + .icon-bar {
  margin-top: 4px;
}

.navbar .nav > .divider {
  height: 2px;
  margin: 9px 0;
  overflow: hidden;
  background-color: #e1e1e1;
  border-bottom: 1px solid #fbfbfb;
}

.navbar-form {
  margin-top: 8px;
  margin-bottom: 8px;
}

.navbar .nav > li > .dropdown-menu {
  margin-top: 0;
  border-top-right-radius: 0;
  border-top-left-radius: 0;
}

.navbar-fixed-bottom .nav > li > .dropdown-menu {
  border-bottom-right-radius: 0;
  border-bottom-left-radius: 0;
}

.navbar .nav li.dropdown > a:hover .caret,
.navbar .nav li.dropdown > a:focus .caret {
  border-top-color: #333333;
  border-bottom-color: #333333;
}

.navbar .nav li.dropdown.open > .dropdown-toggle,
.navbar .nav li.dropdown.active > .dropdown-toggle,
.navbar .nav li.dropdown.open.active > .dropdown-toggle {
  color: #555555;
  background-color: #d5d5d5;
}

.navbar .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #777777;
  border-bottom-color: #777777;
}

.navbar .nav li.dropdown.open > .dropdown-toggle .caret,
.navbar .nav li.dropdown.active > .dropdown-toggle .caret,
.navbar .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #555555;
  border-bottom-color: #555555;
}

.navbar .pull-right > li > .dropdown-menu,
.navbar .nav > li > .dropdown-menu.pull-right {
  right: 0;
  left: auto;
}

.navbar-inverse {
  background-color: #222222;
}

.navbar-inverse .navbar-brand {
  color: #d3d7cf;
}

.navbar-inverse .navbar-brand:hover,
.navbar-inverse .navbar-brand:focus {
  color: #ffffff;
  background-color: transparent;
}

.navbar-inverse .navbar-text {
  color: #d3d7cf;
}

.navbar-inverse .nav > li > a {
  color: #d3d7cf;
}

.navbar-inverse .nav > li > a:hover,
.navbar-inverse .nav > li > a:focus {
  color: #ffffff;
  background-color: transparent;
}

.navbar-inverse .nav > .active > a,
.navbar-inverse .nav > .active > a:hover,
.navbar-inverse .nav > .active > a:focus {
  color: #ffffff;
  background-color: #080808;
}

.navbar-inverse .nav > .disabled > a,
.navbar-inverse .nav > .disabled > a:hover,
.navbar-inverse .nav > .disabled > a:focus {
  color: #444444;
  background-color: transparent;
}

.navbar-inverse .navbar-toggle {
  border-color: #333;
}

.navbar-inverse .navbar-toggle:hover,
.navbar-inverse .navbar-toggle:focus {
  background-color: #333;
}

.navbar-inverse .navbar-toggle .icon-bar {
  background-color: #fff;
}

.navbar-inverse .nav > .divider {
  background-color: #151515;
  border-bottom-color: #2f2f2f;
}

.navbar-inverse .nav li.dropdown.open > .dropdown-toggle,
.navbar-inverse .nav li.dropdown.active > .dropdown-toggle,
.navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle {
  color: #ffffff;
  background-color: #080808;
}

.navbar-inverse .nav li.dropdown > a:hover .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}

.navbar-inverse .nav li.dropdown > .dropdown-toggle .caret {
  border-top-color: #d3d7cf;
  border-bottom-color: #d3d7cf;
}

.navbar-inverse .nav li.dropdown.open > .dropdown-toggle .caret,
.navbar-inverse .nav li.dropdown.active > .dropdown-toggle .caret,
.navbar-inverse .nav li.dropdown.open.active > .dropdown-toggle .caret {
  border-top-color: #ffffff;
  border-bottom-color: #ffffff;
}

@media screen and (min-width: 768px) {
  .navbar {
    padding-top: 0;
    padding-bottom: 0;
  }
  .navbar-brand {
    float: left;
    padding-top: 15px;
    padding-bottom: 15px;
    margin-left: -10px;
  }
  .navbar .nav {
    float: left;
    margin-top: 0;
  }
  .navbar .nav:before,
  .navbar .nav:after {
    display: table;
    content: " ";
  }
  .navbar .nav:after {
    clear: both;
  }
  .navbar .nav:before,
  .navbar .nav:after {
    display: table;
    content: " ";
  }
  .navbar .nav:after {
    clear: both;
  }
  .navbar .nav.pull-right {
    float: right;
  }
  .navbar .nav > li {
    float: left;
  }
  .navbar .nav > .divider {
    width: 1px;
    height: 30px;
    margin: 10px 9px;
    border-right: 1px solid #fbfbfb;
    border-bottom: 0;
  }
  .navbar-inverse .nav > .divider {
    border-right-color: #2f2f2f;
  }
  .navbar-fixed-left {
    padding-right: 0;
    padding-left: 0;
  }
  .navbar-fixed-left .navbar-brand,
  .navbar-fixed-left .nav,
  .navbar-fixed-left .nav > li {
    float: none;
  }
  .navbar-toggle {
    position: relative;
    top: auto;
    left: auto;
    display: none;
  }
  .nav-collapse.collapse {
    height: auto !important;
    overflow: visible !important;
  }
}

/*

// Janky solution for now to account for links outside the .nav
// -------------------------
.navbar-link {
  color: @navbar-link-color;
  &:hover {
    color: @navbar-link-hover-color;
  }
}

// Buttons in navbar
// -------------------------
.navbar .btn,
.navbar .btn-group {
  .navbarVerticalAlign(30px); // Vertically center in navbar
}
.navbar .btn-group .btn,
.navbar .input-prepend .btn,
.navbar .input-append .btn {
  margin-top: 0; // then undo the margin here so we don't accidentally double it
}

// Navbar forms
// -------------------------
.navbar-form {
  margin-bottom: 0; // remove default bottom margin
  .clearfix();
  input,
  select,
  .radio,
  .checkbox {
    .navbarVerticalAlign(30px); // Vertically center in navbar
  }
  input,
  select,
  .btn {
    display: inline-block;
    margin-bottom: 0;
  }
  input[type="image"],
  input[type="checkbox"],
  input[type="radio"] {
    margin-top: 3px;
  }
  .input-append,
  .input-prepend {
    margin-top: 5px;
    white-space: nowrap; // preven two  items from separating within a .navbar-form that has .pull-left
    input {
      margin-top: 0; // remove the margin on top since it's on the parent
    }
  }
}

*/

.navbar-fixed-top.Neverland#top-big ~ .container.Neverland {
  margin-top: 110px;
}

.navbar-fixed-top.Neverland#top-small ~ .container.Neverland {
  margin-top: 70px;
}

@media (max-width: 979px) {
  .navbar-fixed-top.Neverland {
    position: absolute;
  }
}

.navbar-fixed-top.Neverland {
  background: transparent url("//cdn.kde.org/img/bg.png");
  -webkit-box-shadow: 0px 4px 10px 1px #f7f7f9;
          box-shadow: 0px 4px 10px 1px #f7f7f9;
}

.navbar-fixed-top.Neverland .nav li a {
  color: #2e3436;
}

.navbar-fixed-top.Neverland .nav li a i {
  color: #0068c6;
}

.navbar-fixed-top.Neverland .nav li a:hover {
  color: #2e3436;
}

.navbar-fixed-top.Neverland .nav li a:hover i {
  color: #204a87;
}

.navbar-fixed-top.Neverland .nav li a h2 {
  max-width: 230px;
  padding: 0;
  margin-top: 0;
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 1.5em;
  line-height: 1em;
  color: #2e3436;
}

.navbar-fixed-top.Neverland .nav li a h2 small {
  padding-top: 0.3em;
  font-size: 0.61em;
  line-height: 1.2em;
  color: #636363;
}

.navbar-inverse {
  background-color: #2e3436;
  background-image: -moz-linear-gradient(top, #454f52, #2e3436);
  background-image: -webkit-gradient(linear, 0 0, 0 100%, from(#454f52), to(#2e3436));
  background-image: -webkit-linear-gradient(top, #454f52, #2e3436);
  background-image: -o-linear-gradient(top, #454f52, #2e3436);
  background-image: linear-gradient(to bottom, #454f52, #2e3436);
  background-repeat: repeat-x;
  border-color: #252525;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#ff454f52', endColorstr='#ff2e3436', GradientType=0);
}

.navbar-inverse.Neverland .nav > li > a {
  padding-top: 10px;
  padding-bottom: 10px;
}

.btn .caret {
  border-top-color: #ffffff;
}

.dropup .btn .caret {
  border-bottom-color: #ffffff;
}

.btn-group {
  position: relative;
  display: inline-block;
  vertical-align: middle;
}

.btn-group > .btn {
  position: relative;
  float: left;
}

.btn-group > .btn + btn {
  margin-left: -1px;
}

.btn-group > .btn:hover,
.btn-group > .btn:active {
  z-index: 2;
}

.btn-toolbar:before,
.btn-toolbar:after {
  display: table;
  content: " ";
}

.btn-toolbar:after {
  clear: both;
}

.btn-toolbar:before,
.btn-toolbar:after {
  display: table;
  content: " ";
}

.btn-toolbar:after {
  clear: both;
}

.btn-toolbar .btn-group {
  float: left;
}

.btn-toolbar > .btn + .btn,
.btn-toolbar > .btn-group + .btn,
.btn-toolbar > .btn + .btn-group,
.btn-toolbar > .btn-group + .btn-group {
  margin-left: 5px;
}

.btn-group > .btn {
  position: relative;
  border-radius: 0;
}

.btn-group > .btn:first-child {
  margin-left: 0;
  border-bottom-left-radius: 2px;
  border-top-left-radius: 2px;
}

.btn-group > .btn:last-child,
.btn-group > .dropdown-toggle {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

.btn-group > .btn.large:first-child {
  margin-left: 0;
  border-bottom-left-radius: 3px;
  border-top-left-radius: 3px;
}

.btn-group > .btn.large:last-child,
.btn-group > .large.dropdown-toggle {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

.btn-group .dropdown-toggle:active,
.btn-group.open .dropdown-toggle {
  outline: 0;
}

.btn-group > .btn + .dropdown-toggle {
  padding-right: 8px;
  padding-left: 8px;
}

.btn-group > .btn-mini + .dropdown-toggle {
  padding-right: 5px;
  padding-left: 5px;
}

.btn-group > .btn-large + .dropdown-toggle {
  padding-right: 12px;
  padding-left: 12px;
}

.btn-group.open .dropdown-toggle {
  -webkit-box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
          box-shadow: inset 0 3px 5px rgba(0, 0, 0, 0.125);
}

.btn .caret {
  margin-top: 8px;
  margin-left: 0;
}

.btn-large .caret {
  border-width: 5px;
}

.dropup .btn-large .caret {
  border-bottom-width: 5px;
}

.btn-group-vertical > .btn {
  display: block;
  float: none;
  width: 100%;
  max-width: 100%;
}

.btn-group-vertical .btn:first-child {
  border-radius: 0;
  border-top-right-radius: 2px;
  border-top-left-radius: 2px;
}

.btn-group-vertical .btn:last-child {
  border-radius: 0;
  border-bottom-right-radius: 2px;
  border-bottom-left-radius: 2px;
}

.btn-group-vertical .btn-large:first-child {
  border-top-right-radius: 3px;
  border-top-left-radius: 3px;
}

.btn-group-vertical .btn-large:last-child {
  border-bottom-right-radius: 3px;
  border-bottom-left-radius: 3px;
}

.btn-group-justified {
  display: table;
  width: 100%;
}

.btn-group-justified .btn {
  display: table-cell;
  float: none;
  width: 1%;
}

.btn-group[data-toggle="buttons-radio"] > .btn > input[type="radio"],
.btn-group[data-toggle="buttons-checkbox"] > .btn > input[type="checkbox"] {
  display: none;
}

.breadcrumb {
  padding: 8px 15px;
  margin: 0 0 20px;
  list-style: none;
  background-color: #f5f5f5;
  border-radius: 2px;
}

.breadcrumb > li {
  display: inline-block;
  text-shadow: 0 1px 0 #fff;
}

.breadcrumb > li:after {
  display: inline-block;
  padding: 0 5px;
  color: #ccc;
  content: "\00a0 /";
}

.breadcrumb > li:last-child:after {
  content: "";
}

.breadcrumb > .active {
  color: #d3d7cf;
}

.pagination {
  display: inline-block;
  margin: 20px 0;
  border-radius: 2px;
}

.pagination > li {
  display: inline;
}

.pagination > li > a,
.pagination > li > span {
  float: left;
  padding: 4px 12px;
  line-height: 20px;
  text-decoration: none;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-left-width: 0;
}

.pagination > li > a:hover,
.pagination > li > a:focus,
.pagination > .active > a,
.pagination > .active > span {
  background-color: #f5f5f5;
}

.pagination > .active > a,
.pagination > .active > span {
  color: #d3d7cf;
  cursor: default;
}

.pagination > .disabled > span,
.pagination > .disabled > a,
.pagination > .disabled > a:hover,
.pagination > .disabled > a:focus {
  color: #d3d7cf;
  cursor: default;
  background-color: #ffffff;
}

.pagination > li:first-child > a,
.pagination > li:first-child > span {
  border-left-width: 1px;
  border-bottom-left-radius: 2px;
  border-top-left-radius: 2px;
}

.pagination > li:last-child > a,
.pagination > li:last-child > span {
  border-top-right-radius: 2px;
  border-bottom-right-radius: 2px;
}

.pagination-large > li > a,
.pagination-large > li > span {
  padding: 11px 14px;
  font-size: 17.5px;
}

.pagination-large > li:first-child > a,
.pagination-large > li:first-child > span {
  border-bottom-left-radius: 3px;
  border-top-left-radius: 3px;
}

.pagination-large > li:last-child > a,
.pagination-large > li:last-child > span {
  border-top-right-radius: 3px;
  border-bottom-right-radius: 3px;
}

.pagination-mini > li:first-child > a,
.pagination-small > li:first-child > a,
.pagination-mini > li:first-child > span,
.pagination-small > li:first-child > span {
  border-bottom-left-radius: 1px;
  border-top-left-radius: 1px;
}

.pagination-mini > li:last-child > a,
.pagination-small > li:last-child > a,
.pagination-mini > li:last-child > span,
.pagination-small > li:last-child > span {
  border-top-right-radius: 1px;
  border-bottom-right-radius: 1px;
}

.pagination-small > li > a,
.pagination-small > li > span {
  padding: 2px 10px;
  font-size: 11.9px;
}

.pagination-mini > li > a,
.pagination-mini > li > span {
  padding: 0 6px;
  font-size: 10.5px;
}

.pager {
  margin: 20px 0;
  text-align: center;
  list-style: none;
}

.pager:before,
.pager:after {
  display: table;
  content: " ";
}

.pager:after {
  clear: both;
}

.pager:before,
.pager:after {
  display: table;
  content: " ";
}

.pager:after {
  clear: both;
}

.pager li {
  display: inline;
}

.pager li > a,
.pager li > span {
  display: inline-block;
  padding: 5px 14px;
  background-color: #ffffff;
  border: 1px solid #dddddd;
  border-radius: 15px;
}

.pager li > a:hover,
.pager li > a:focus {
  text-decoration: none;
  background-color: #f5f5f5;
}

.pager .next > a,
.pager .next > span {
  float: right;
}

.pager .previous > a,
.pager .previous > span {
  float: left;
}

.pager .disabled > a,
.pager .disabled > a:hover,
.pager .disabled > a:focus,
.pager .disabled > span {
  color: #d3d7cf;
  cursor: default;
  background-color: #fff;
}

.modal-open {
  overflow: hidden;
}

.modal {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1040;
  display: none;
  overflow: auto;
  overflow-y: scroll;
  -webkit-overflow-scrolling: touch;
}

.modal.fade {
  top: -25%;
  -webkit-transition: opacity 0.3s linear, top 0.3s ease-out;
     -moz-transition: opacity 0.3s linear, top 0.3s ease-out;
       -o-transition: opacity 0.3s linear, top 0.3s ease-out;
          transition: opacity 0.3s linear, top 0.3s ease-out;
}

.modal.fade.in {
  top: 0;
}

.modal-dialog {
  position: relative;
  top: 0;
  right: 0;
  left: 0;
  z-index: 1050;
  width: auto;
  padding: 10px;
}

.modal-content {
  position: relative;
  background-color: #fff;
  border: 1px solid #999;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  outline: none;
  -webkit-box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
          box-shadow: 0 3px 9px rgba(0, 0, 0, 0.5);
  -webkit-background-clip: padding-box;
     -moz-background-clip: padding-box;
          background-clip: padding-box;
}

.modal-backdrop {
  position: fixed;
  top: 0;
  right: 0;
  bottom: 0;
  left: 0;
  z-index: 1030;
  background-color: #000;
}

.modal-backdrop.fade {
  opacity: 0;
  filter: alpha(opacity=0);
}

.modal-backdrop.fade.in {
  opacity: 0.5;
  filter: alpha(opacity=50);
}

.modal-header {
  padding: 9px 15px;
  border-bottom: 1px solid #e5e5e5;
}

.modal-header .close {
  margin-top: 2px;
}

.modal-title {
  margin: 0;
  line-height: 30px;
}

.modal-body {
  position: relative;
  padding: 20px;
}

.modal-footer {
  padding: 19px 20px 20px;
  margin-top: 15px;
  text-align: right;
  border-top: 1px solid #e5e5e5;
}

.modal-footer:before,
.modal-footer:after {
  display: table;
  content: " ";
}

.modal-footer:after {
  clear: both;
}

.modal-footer:before,
.modal-footer:after {
  display: table;
  content: " ";
}

.modal-footer:after {
  clear: both;
}

.modal-footer .btn + .btn {
  margin-bottom: 0;
  margin-left: 5px;
}

.modal-footer .btn-group .btn + .btn {
  margin-left: -1px;
}

.modal-footer .btn-block + .btn-block {
  margin-left: 0;
}

@media screen and (min-width: 768px) {
  .modal-dialog {
    right: auto;
    left: 50%;
    width: 560px;
    padding-top: 30px;
    padding-bottom: 30px;
    margin-left: -280px;
  }
  .modal-content {
    -webkit-box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
            box-shadow: 0 5px 15px rgba(0, 0, 0, 0.5);
  }
}

.tooltip {
  position: absolute;
  z-index: 1030;
  display: block;
  font-size: 11px;
  line-height: 1.4;
  opacity: 0;
  filter: alpha(opacity=0);
  visibility: visible;
}

.tooltip.in {
  opacity: 1;
  filter: alpha(opacity=100);
}

.tooltip.top {
  padding: 5px 0;
  margin-top: -3px;
}

.tooltip.right {
  padding: 0 5px;
  margin-left: 3px;
}

.tooltip.bottom {
  padding: 5px 0;
  margin-top: 3px;
}

.tooltip.left {
  padding: 0 5px;
  margin-left: -3px;
}

.tooltip-inner {
  max-width: 200px;
  padding: 3px 8px;
  color: #ffffff;
  text-align: center;
  text-decoration: none;
  background-color: rgba(0, 0, 0, 0.9);
  border-radius: 2px;
}

.tooltip-arrow {
  position: absolute;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}

.tooltip.top .tooltip-arrow {
  bottom: 0;
  left: 50%;
  margin-left: -5px;
  border-top-color: rgba(0, 0, 0, 0.9);
  border-width: 5px 5px 0;
}

.tooltip.right .tooltip-arrow {
  top: 50%;
  left: 0;
  margin-top: -5px;
  border-right-color: rgba(0, 0, 0, 0.9);
  border-width: 5px 5px 5px 0;
}

.tooltip.left .tooltip-arrow {
  top: 50%;
  right: 0;
  margin-top: -5px;
  border-left-color: rgba(0, 0, 0, 0.9);
  border-width: 5px 0 5px 5px;
}

.tooltip.bottom .tooltip-arrow {
  top: 0;
  left: 50%;
  margin-left: -5px;
  border-bottom-color: rgba(0, 0, 0, 0.9);
  border-width: 0 5px 5px;
}

.popover {
  position: absolute;
  top: 0;
  left: 0;
  z-index: 1010;
  display: none;
  max-width: 276px;
  padding: 1px;
  text-align: left;
  white-space: normal;
  background-color: #ffffff;
  border: 1px solid #ccc;
  border: 1px solid rgba(0, 0, 0, 0.2);
  border-radius: 6px;
  -webkit-box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
          box-shadow: 0 5px 10px rgba(0, 0, 0, 0.2);
  background-clip: padding-box;
  -webkit-bg-clip: padding-box;
     -moz-bg-clip: padding;
}

.popover.top {
  margin-top: -10px;
}

.popover.right {
  margin-left: 10px;
}

.popover.bottom {
  margin-top: 10px;
}

.popover.left {
  margin-left: -10px;
}

.popover-title {
  padding: 8px 14px;
  margin: 0;
  font-size: 14px;
  font-weight: normal;
  line-height: 18px;
  background-color: #f7f7f7;
  border-bottom: 1px solid #ebebeb;
  border-radius: 5px 5px 0 0;
}

.popover-title:empty {
  display: none;
}

.popover-content {
  padding: 9px 14px;
}

.popover .arrow,
.popover .arrow:after {
  position: absolute;
  display: block;
  width: 0;
  height: 0;
  border-color: transparent;
  border-style: solid;
}

.popover .arrow {
  border-width: 11px;
}

.popover .arrow:after {
  border-width: 10px;
  content: "";
}

.popover.top .arrow {
  bottom: -11px;
  left: 50%;
  margin-left: -11px;
  border-top-color: #999;
  border-top-color: rgba(0, 0, 0, 0.25);
  border-bottom-width: 0;
}

.popover.top .arrow:after {
  bottom: 1px;
  margin-left: -10px;
  border-top-color: #ffffff;
  border-bottom-width: 0;
}

.popover.right .arrow {
  top: 50%;
  left: -11px;
  margin-top: -11px;
  border-right-color: #999;
  border-right-color: rgba(0, 0, 0, 0.25);
  border-left-width: 0;
}

.popover.right .arrow:after {
  bottom: -10px;
  left: 1px;
  border-right-color: #ffffff;
  border-left-width: 0;
}

.popover.bottom .arrow {
  top: -11px;
  left: 50%;
  margin-left: -11px;
  border-bottom-color: #999;
  border-bottom-color: rgba(0, 0, 0, 0.25);
  border-top-width: 0;
}

.popover.bottom .arrow:after {
  top: 1px;
  margin-left: -10px;
  border-bottom-color: #ffffff;
  border-top-width: 0;
}

.popover.left .arrow {
  top: 50%;
  right: -11px;
  margin-top: -11px;
  border-left-color: #999;
  border-left-color: rgba(0, 0, 0, 0.25);
  border-right-width: 0;
}

.popover.left .arrow:after {
  right: 1px;
  bottom: -10px;
  border-left-color: #ffffff;
  border-right-width: 0;
}

.alert {
  padding: 8px 35px 8px 14px;
  margin-bottom: 20px;
  color: #c38800;
  background-color: #ffedc3;
  border: 1px solid #ffcb90;
  border-radius: 2px;
}

.alert h4 {
  margin-top: 0;
  color: inherit;
}

.alert hr {
  border-top-color: #ffbf77;
}

.alert > a,
.alert > p > a {
  font-weight: 500;
  color: #906500;
}

.close {
  position: relative;
  top: -2px;
  right: -21px;
  line-height: 20px;
  color: inherit;
}

.alert-success {
  color: #759300;
  background-color: #f3ffc6;
  border-color: #fbff93;
}

.alert-success hr {
  border-top-color: #faff7a;
}

.alert-success > a,
.alert-success > p > a {
  color: #4c6000;
}

.alert-danger,
.alert-error {
  color: #c6001e;
  background-color: #ffc6cf;
  border-color: #ff93b5;
}

.alert-danger hr,
.alert-error hr {
  border-top-color: #ff7aa4;
}

.alert-danger > a,
.alert-error > a,
.alert-danger > p > a,
.alert-error > p > a {
  color: #930016;
}

.alert-info {
  color: #0068c6;
  background-color: #c6e4ff;
  border-color: #93deff;
}

.alert-info hr {
  border-top-color: #7ad6ff;
}

.alert-info > a,
.alert-info > p > a {
  color: #004d93;
}

.alert-block {
  padding-top: 14px;
  padding-bottom: 14px;
}

.alert-block > p,
.alert-block > ul {
  margin-bottom: 0;
}

.alert-block p + p {
  margin-top: 5px;
}

.alert {
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.thumbnail,
.img-thumbnail {
  padding: 4px;
  line-height: 20px;
  border: 1px solid #ddd;
  border-radius: 2px;
  -webkit-transition: all 0.2s ease-in-out;
     -moz-transition: all 0.2s ease-in-out;
       -o-transition: all 0.2s ease-in-out;
          transition: all 0.2s ease-in-out;
}

.thumbnail {
  display: block;
}

.img-thumbnail {
  display: inline-block;
}

a.thumbnail:hover,
a.thumbnail:focus {
  border-color: #0068c6;
}

.thumbnail > img {
  display: block;
  max-width: 100%;
  margin-right: auto;
  margin-left: auto;
}

.thumbnail .caption {
  padding: 9px;
  color: #9c9c9c;
}

.media,
.media-body {
  overflow: hidden;
  zoom: 1;
}

.media,
.media .media {
  margin-top: 15px;
}

.media:first-child {
  margin-top: 0;
}

.media-object {
  display: block;
}

.media-heading {
  margin: 0 0 5px;
}

.media > .pull-left {
  margin-right: 10px;
}

.media > .pull-right {
  margin-left: 10px;
}

.media-list {
  margin-left: 0;
  list-style: none;
}

.label {
  padding: .25em .6em;
  font-size: 75%;
  font-weight: 500;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  background-color: #d3d7cf;
  border-radius: .25em;
}

a.label:hover,
a.label:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}

.label-danger {
  background-color: #c6001e;
}

.label-danger[href] {
  background-color: #930016;
}

.label-warning {
  background-color: #f6ac00;
}

.label-warning[href] {
  background-color: #c38800;
}

.label-success {
  background-color: #9dc600;
}

.label-success[href] {
  background-color: #759300;
}

.label-info {
  background-color: #0068c6;
}

.label-info[href] {
  background-color: #004d93;
}

.badge {
  display: inline-block;
  min-width: 10px;
  padding: 3px 7px;
  font-size: 12px;
  font-weight: bold;
  line-height: 1;
  color: #fff;
  text-align: center;
  white-space: nowrap;
  vertical-align: middle;
  background-color: #d3d7cf;
  border-radius: 10px;
}

.badge:empty {
  display: none;
}

a.badge:hover,
a.badge:focus {
  color: #fff;
  text-decoration: none;
  cursor: pointer;
}

.btn .badge {
  position: relative;
  top: -1px;
}

.btn-mini .badge {
  top: 0;
}

a.list-group-item.active > .badge,
.nav-pills > .active > a > .badge {
  color: #0068c6;
  background-color: #fff;
}

.nav-pills > li > a > .badge {
  margin-left: 3px;
}

@-webkit-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}

@-moz-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}

@-ms-keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}

@-o-keyframes progress-bar-stripes {
  from {
    background-position: 0 0;
  }
  to {
    background-position: 40px 0;
  }
}

@keyframes progress-bar-stripes {
  from {
    background-position: 40px 0;
  }
  to {
    background-position: 0 0;
  }
}

.progress {
  height: 20px;
  margin-bottom: 20px;
  overflow: hidden;
  background-color: #f5f5f5;
  border-radius: 2px;
  -webkit-box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
          box-shadow: inset 0 1px 2px rgba(0, 0, 0, 0.1);
}

.progress-bar {
  float: left;
  width: 0;
  height: 100%;
  font-size: 12px;
  color: #fff;
  text-align: center;
  text-shadow: 0 -1px 0 rgba(0, 0, 0, 0.25);
  background-color: #0068c6;
  -webkit-box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
          box-shadow: inset 0 -1px 0 rgba(0, 0, 0, 0.15);
  -webkit-transition: width 0.6s ease;
     -moz-transition: width 0.6s ease;
       -o-transition: width 0.6s ease;
          transition: width 0.6s ease;
}

.progress-striped .progress-bar {
  background-color: #0068c6;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  -webkit-background-size: 40px 40px;
     -moz-background-size: 40px 40px;
       -o-background-size: 40px 40px;
          background-size: 40px 40px;
}

.progress.active .progress-bar {
  -webkit-animation: progress-bar-stripes 2s linear infinite;
     -moz-animation: progress-bar-stripes 2s linear infinite;
      -ms-animation: progress-bar-stripes 2s linear infinite;
       -o-animation: progress-bar-stripes 2s linear infinite;
          animation: progress-bar-stripes 2s linear infinite;
}

.progress-bar-danger {
  background-color: #c6001e;
}

.progress-striped .progress-bar-danger {
  background-color: #c6001e;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}

.progress-bar-success {
  background-color: #9dc600;
}

.progress-striped .progress-bar-success {
  background-color: #9dc600;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}

.progress-bar-warning {
  background-color: #f6ac00;
}

.progress-striped .progress-bar-warning {
  background-color: #f6ac00;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}

.progress-bar-info {
  background-color: #0068c6;
}

.progress-striped .progress-bar-info {
  background-color: #0068c6;
  background-image: -webkit-gradient(linear, 0 100%, 100% 0, color-stop(0.25, rgba(255, 255, 255, 0.15)), color-stop(0.25, transparent), color-stop(0.5, transparent), color-stop(0.5, rgba(255, 255, 255, 0.15)), color-stop(0.75, rgba(255, 255, 255, 0.15)), color-stop(0.75, transparent), to(transparent));
  background-image: -webkit-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -moz-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: -o-linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
  background-image: linear-gradient(45deg, rgba(255, 255, 255, 0.15) 25%, transparent 25%, transparent 50%, rgba(255, 255, 255, 0.15) 50%, rgba(255, 255, 255, 0.15) 75%, transparent 75%, transparent);
}

.accordion {
  margin-bottom: 20px;
}

.accordion-group {
  margin-bottom: 2px;
  border: 1px solid #e5e5e5;
  border-radius: 2px;
}

.accordion-heading {
  border-bottom: 0;
}

.accordion-heading .accordion-toggle {
  display: block;
  padding: 8px 15px;
}

.accordion-toggle {
  cursor: pointer;
}

.accordion-inner {
  padding: 9px 15px;
  border-top: 1px solid #e5e5e5;
}

.carousel {
  position: relative;
}

.carousel-inner {
  position: relative;
  width: 100%;
  overflow: hidden;
}

.carousel-inner > .item {
  position: relative;
  display: none;
  -webkit-transition: 0.6s ease-in-out left;
     -moz-transition: 0.6s ease-in-out left;
       -o-transition: 0.6s ease-in-out left;
          transition: 0.6s ease-in-out left;
}

.carousel-inner > .item > img,
.carousel-inner > .item > a > img {
  display: block;
  line-height: 1;
}

.carousel-inner > .active,
.carousel-inner > .next,
.carousel-inner > .prev {
  display: block;
}

.carousel-inner > .active {
  left: 0;
}

.carousel-inner > .next,
.carousel-inner > .prev {
  position: absolute;
  top: 0;
  width: 100%;
}

.carousel-inner > .next {
  left: 100%;
}

.carousel-inner > .prev {
  left: -100%;
}

.carousel-inner > .next.left,
.carousel-inner > .prev.right {
  left: 0;
}

.carousel-inner > .active.left {
  left: -100%;
}

.carousel-inner > .active.right {
  left: 100%;
}

.carousel-control {
  position: absolute;
  top: 0;
  bottom: 0;
  left: 0;
  width: 15%;
  font-size: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
  opacity: 0.5;
  filter: alpha(opacity=50);
}

.carousel-control.left {
  background-color: rgba(0, 0, 0, 0.0001);
  background-color: transparent;
  background-image: -moz-linear-gradient(left, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.0001));
  background-image: -webkit-gradient(linear, 0 0, 100% 0, from(rgba(0, 0, 0, 0.5)), to(rgba(0, 0, 0, 0.0001)));
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.0001));
  background-image: -o-linear-gradient(left, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.0001));
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.5), rgba(0, 0, 0, 0.0001));
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#80000000', endColorstr='#00000000', GradientType=1);
}

.carousel-control.right {
  right: 0;
  left: auto;
  background-color: rgba(0, 0, 0, 0.5);
  background-color: transparent;
  background-image: -moz-linear-gradient(left, rgba(0, 0, 0, 0.0001), rgba(0, 0, 0, 0.5));
  background-image: -webkit-gradient(linear, 0 0, 100% 0, from(rgba(0, 0, 0, 0.0001)), to(rgba(0, 0, 0, 0.5)));
  background-image: -webkit-linear-gradient(left, rgba(0, 0, 0, 0.0001), rgba(0, 0, 0, 0.5));
  background-image: -o-linear-gradient(left, rgba(0, 0, 0, 0.0001), rgba(0, 0, 0, 0.5));
  background-image: linear-gradient(to right, rgba(0, 0, 0, 0.0001), rgba(0, 0, 0, 0.5));
  background-repeat: repeat-x;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#00000000', endColorstr='#80000000', GradientType=1);
}

.carousel-control:hover,
.carousel-control:focus {
  color: #fff;
  text-decoration: none;
  opacity: 0.9;
  filter: alpha(opacity=90);
}

.carousel-control .glyphicon {
  position: absolute;
  top: 50%;
  left: 50%;
  z-index: 5;
  display: inline-block;
  width: 20px;
  height: 20px;
  margin-top: -10px;
  margin-left: -10px;
}

.carousel-indicators {
  position: absolute;
  bottom: 20px;
  left: 50%;
  z-index: 5;
  width: 100px;
  margin: 0 0 0 -50px;
  text-align: center;
  list-style: none;
}

.carousel-indicators li {
  display: inline-block;
  width: 8px;
  height: 8px;
  margin-right: 0;
  margin-left: 0;
  text-indent: -999px;
  cursor: pointer;
  border: 1px solid #fff;
  border-radius: 5px;
}

.carousel-indicators .active {
  background-color: #fff;
}

.carousel-caption {
  position: absolute;
  right: 15%;
  bottom: 20px;
  left: 15%;
  z-index: 10;
  padding-top: 20px;
  padding-bottom: 20px;
  color: #fff;
  text-align: center;
  text-shadow: 0 1px 2px rgba(0, 0, 0, 0.6);
}

.carousel-caption .btn {
  text-shadow: none;
}

@media screen and (min-width: 768px) {
  .carousel-control .glyphicon {
    width: 30px;
    height: 30px;
    margin-top: -15px;
    margin-left: -15px;
    font-size: 30px;
  }
  .carousel-caption {
    right: 20%;
    left: 20%;
    padding-bottom: 30px;
  }
}

.carousel .carousel-caption {
  bottom: 0;
  z-index: 0;
  max-width: 100%;
  padding: 5px 30px;
  margin: 0;
  background-color: rgba(46, 52, 54, 0.7);
  -webkit-box-shadow: 0 0px 3px 1px rgba(0, 0, 0, 0.6);
          box-shadow: 0 0px 3px 1px rgba(0, 0, 0, 0.6);
}

.carousel .carousel-caption h3 {
  color: #ffffff;
}

.carousel .carousel-indicators {
  bottom: 75px;
}

.carousel .item img {
  margin: 0 auto;
}

.jumbotron {
  padding: 30px;
  margin-bottom: 30px;
  font-size: 21px;
  font-weight: 200;
  line-height: 30px;
  color: inherit;
  background-color: #fafafa;
}

.jumbotron h1 {
  line-height: 1;
  color: inherit;
}

.jumbotron p {
  line-height: 1.4;
}

@media screen and (min-width: 768px) {
  .jumbotron {
    padding: 50px 60px;
    border-radius: 6px;
  }
  .jumbotron h1 {
    font-size: 60px;
  }
}

.clearfix:before,
.clearfix:after {
  display: table;
  content: " ";
}

.clearfix:after {
  clear: both;
}

.pull-right {
  float: right;
}

.pull-left {
  float: left;
}

.hide {
  display: none !important;
}

.show {
  display: block !important;
}

.invisible {
  visibility: hidden;
}

.text-hide {
  font: 0/0 a;
  color: transparent;
  text-shadow: none;
  background-color: transparent;
  border: 0;
}

.affix {
  position: fixed;
}

@-ms-viewport {
  width: device-width;
}

.hidden {
  display: none;
  visibility: hidden;
}

.visible-phone {
  display: none !important;
}

.visible-tablet {
  display: none !important;
}

.hidden-desktop {
  display: none !important;
}

.visible-desktop {
  display: inherit !important;
}

@media (min-width: 768px) and (max-width: 979px) {
  .hidden-desktop {
    display: inherit !important;
  }
  .visible-desktop {
    display: none !important ;
  }
  .visible-tablet {
    display: inherit !important;
  }
  .hidden-tablet {
    display: none !important;
  }
}

@media (max-width: 767px) {
  .hidden-desktop {
    display: inherit !important;
  }
  .visible-desktop {
    display: none !important;
  }
  .visible-phone {
    display: inherit !important;
  }
  .hidden-phone {
    display: none !important;
  }
}

.visible-print {
  display: none !important;
}

@media print {
  .visible-print {
    display: inherit !important;
  }
  .hidden-print {
    display: none !important;
  }
}

.nav-list.Neverland {
  background-color: transparent;
  -webkit-box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
          box-shadow: 0 1px 8px rgba(0, 0, 0, 0.1);
}

.nav-list.Neverland > li > h3 {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  font-size: 1.2em;
  line-height: 1em;
  color: #2e3436;
}

.nav-list.Neverland > li > a h3,
.nav-list.Neverland > li > a small {
  font-family: "Open Sans", "Helvetica Neue", Helvetica, Arial, sans-serif;
  color: #2e3436;
}

.nav-list.Neverland > li > a h3 {
  font-size: 1.2em;
  line-height: 1em;
}

.nav-list.Neverland > li > a:hover,
.nav-list.Neverland > li > a:hover * {
  color: #0068c6;
}

.nav-list.Neverland .active > a h3 {
  color: #ffffff;
  text-shadow: none;
}

.nav-list.Neverland .active > a h3 small {
  color: #ffffff;
  text-shadow: none;
}
